#!/bin/sh
#
# Ein Beispiel der DANTE-Edition
#
#
# Copyright (C) 2013 Herbert Voss
#
# It may be distributed and/or modified under the conditions
# of the LaTeX Project Public License, either version 1.3
# of this license or (at your option) any later version.
#
# See http://www.latex-project.org/lppl.txt for details.
#
# Running otfinfo on Linux
#
#CODEbegin
otfinfo -h
#CODEend
